@@ -16,10 +16,12 @@ memoizedCall <- function(fcn, ...) {
   keyHash <- digest(key)
   filename <- keyHash
 
+  Sys.setenv("DEBUG_SIMPLERCACHE_LAST_HASH"=keyHash)
+  
   if(Sys.getenv("DEBUG_SIMPLERCACHE") != "") {
     cat("keyHash: ", keyHash, "\n")
   }
-  
+
   if(Sys.getenv("PREFIX_SIMPLERCACHE") != "") {
     filename <- paste0(Sys.getenv("PREFIX_SIMPLERCACHE"), "_", keyHash)
   }
@@ -27,13 +29,27 @@ memoizedCall <- function(fcn, ...) {
   pathname <- file.path(getOption("simpleRCacheRoot"), paste0(filename, ".rds"))
 
   if(file.exists(pathname)) {
+    if(Sys.getenv("DEBUG_SIMPLERCACHE") != "") {
+      cat("DEBUG: Cache used: ", pathname, "\n")
+    }
+
     res <- readRDS(pathname)
   } else {
+    if(Sys.getenv("DEBUG_SIMPLERCACHE") != "") {
+      cat("DEBUG: Cache not used: ", pathname, "\n")
+    }
+    
     # 2. Otherwise, call method with arguments
     res <- do.call(fcn, args=list(...))
 
     # 3. Memoize results
     saveRDS(res, file=pathname)
+    
+    if(Sys.getenv("DEBUG_SIMPLERCACHE") != "" && file.exists(pathname)) {
+      cat("DEBUG: Cache saved\n")
+    } else {
+      cat("DEBUG: Cache not saved\n")
+    }
   }
 
   # 4. Return results
